Stan Math Library: stan::math::promote_scalar_struct< T, T > Struct Template Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- Class List
- Class Index
- Class Hierarchy
- Class Members

Static Public Member Functions | List of all members
stan::math::promote_scalar_struct< T, T > Struct Template Reference

Struct to hold static function for promoting underlying scalar types. More...

`#include <promote_scalar.hpp>`

## Static Public Member Functions
static T | apply (const T &x)
| Return the unmodified input. More...

## Detailed Description

### template<typename T>
struct stan::math::promote_scalar_struct< T, T >

Struct to hold static function for promoting underlying scalar types.

This specialization is for equal input and output types of function types.

Template Parameters

  T | input and return type of nested static function.

Definition at line 44 of file promote_scalar.hpp.

## Member Function Documentation

template<typename T >

static T stan::math::promote_scalar_struct< T, T >::apply | ( | const T & | x | ) |
| inlinestatic

Return the unmodified input.

Parameters

  x | input of type T.

Returns
  input unmodified.

Definition at line 51 of file promote_scalar.hpp.

The documentation for this struct was generated from the following file:

- stan/math/prim/scal/fun/promote_scalar.hpp

[ Stan Home Page ] © 2011–2016, Stan Development Team.